@@ -2,4 +2,4 @@ from .basecontainer import BaseContainer
 from .container import Container
 from .labeledcontainer import LabeledContainer
 from .labeledradiobuttongroup import LabeledRadioButtonGroup
-from .labeledwidgetscontainer import LabeledWidgetsContainer
+from .labeledwidget import LabeledWidgetContainer, LabeledWidgetsContainer, LabeledWidgetLabeledContainer
